summaryrefslogtreecommitdiffstatshomepage
path: root/src/devices/sound/lmc1992.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/devices/sound/lmc1992.cpp')
-rw-r--r--src/devices/sound/lmc1992.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/devices/sound/lmc1992.cpp b/src/devices/sound/lmc1992.cpp
index 84eb7f7c9d7..ad412395d9d 100644
--- a/src/devices/sound/lmc1992.cpp
+++ b/src/devices/sound/lmc1992.cpp
@@ -171,11 +171,11 @@ void lmc1992_device::device_start()
//-------------------------------------------------
// sound_stream_update - handle update requests for
// our sound stream
//-------------------------------------------------
-void lmc1992_device::sound_stream_update(sound_stream &stream, stream_sample_t **inputs, stream_sample_t **outputs, int samples)
+void lmc1992_device::sound_stream_update_legacy(sound_stream &stream, stream_sample_t const * const *inputs, stream_sample_t * const *outputs, int samples)
{
}
@@ -171,11 +171,11 @@ void lmc1992_device::device_start()
//-------------------------------------------------
-// sound_stream_update - handle update requests for
+// sound_stream_update_legacy - handle update requests for
// our sound stream
//-------------------------------------------------